@@ -2,15 +2,15 @@ package WWW::Wookie::Widget::Instance;    # -*- cperl; cperl-indent-level: 4 -*-
 use strict;
 use warnings;
 
-# $Id: Instance.pm 350 2010-11-05 22:04:49Z roland $
-# $Revision: 350 $
+# $Id: Instance.pm 357 2010-11-07 10:53:18Z roland $
+# $Revision: 357 $
 # $HeadURL: svn+ssh://ipenburg.xs4all.nl/srv/svnroot/barclay/trunk/lib/WWW/Wookie/Widget/Instance.pm $
-# $Date: 2010-11-05 23:04:49 +0100 (Fri, 05 Nov 2010) $
+# $Date: 2010-11-07 11:53:18 +0100 (Sun, 07 Nov 2010) $
 
 use utf8;
 use 5.006000;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Moose qw/around has/;
 
@@ -87,17 +87,17 @@ __END__
 
 =head1 NAME
 
-WWW::Wookie::Widget::Instance - An instance of a widget for use on the client.
+WWW::Wookie::Widget::Instance - An instance of a widget for use on the client
 
 =head1 VERSION
 
-This document describes WWW::Wookie::Widget::Instance version 0.0.1
+This document describes WWW::Wookie::Widget::Instance version 0.0.2
 
 =head1 SYNOPSIS
 
     use WWW::Wookie::Widget::Instance;
-	$i = WWW::Wookie::Widget::Instance->new(
-		$url, $guid, $title, $height, $width);
+    $i = WWW::Wookie::Widget::Instance->new(
+        $url, $guid, $title, $height, $width);
 
 =head1 DESCRIPTION
 
@@ -109,15 +109,15 @@ Initialize new widget instance.
 
 =over
 
-=item url of the widget as string
+=item 1. Url of the widget as string
 
-=item guid of the widget as string
+=item 2. Guid of the widget as string
 
-=item title of the widget as string
+=item 3. Title of the widget as string
 
-=item height of the widget as string
+=item 4. Height of the widget as string
 
-=item width of the widget as string
+=item 5. Width of the widget as string
 
 =back
 
@@ -131,7 +131,7 @@ Set widget instance url.
 
 =over
 
-=item new url for instance as string
+=item 1. New url for instance as string
 
 =back
 
@@ -145,7 +145,7 @@ Set widget guid value.
 
 =over
 
-=item guid value as string
+=item 1. Guid value as string
 
 =back
 
@@ -159,7 +159,7 @@ Set widget title.
 
 =over
 
-=item new widget title as string
+=item 1. New widget title as string
 
 =back
 
@@ -173,7 +173,7 @@ Set widget height.
 
 =over
 
-=item new widget height as integer
+=item 1. New widget height as integer
 
 =back
 
@@ -187,7 +187,7 @@ Set widget width.
 
 =over
 
-=item new widget width as integer
+=item 1. New widget width as integer
 
 =back
 
@@ -204,6 +204,9 @@ L<Readonly|Readonly>
 
 =head1 BUGS AND LIMITATIONS
 
+Please report any bugs or feature requests at L<RT for
+rt.cpan.org|https://rt.cpan.org/Dist/Display.html?Queue=WWW-Wookie>.
+
 =head1 AUTHOR
 
 Roland van Ipenburg  C<< <ipenburg@xs4all.nl> >>
